==> reactors-router-3.1.23.tgz: package/app/Router.js <==
// @flow
import {Animated, View} from 'reactors';
import compact from 'lodash/compact';
import findIndex from 'lodash/findIndex';
import first from 'lodash/first';
import get from 'lodash/get';
import includes from 'lodash/includes';
import omit from 'lodash/omit';
import pick from 'lodash/pick';
import React, {Component} from 'react';
import ReactDOM from 'react-dom';

import Route from './Route';

type $ReactorsRouterProps = {
  containerStyle: any,
};

export default class ReactorsRouter extends Component {

  static routers = {};

  static Route = Route;

  static get = name => ReactorsRouter.routers[name];

  static getRoute = (routeName, routes, mounted) => {
    let current;
    let currentIndex;
    routes.forEach((route, index) => {
      if (
        route.props.name === routeName &&
        includes(mounted, route.props.name)
      ) {
        current = route;
        currentIndex = index;
      }
    });
    return {...current, index: currentIndex};
  };

  static makeState = (props) => {
    const routes = React.Children.toArray(props.children);
    const currentRoute = ReactorsRouter.getRoute(props.initial, routes);
    const state = {routes};
    if (currentRoute) {
      state.current = currentRoute.name;
    } else {
      state.current = first(routes).name;
    }
    return state;
  };

  state = ReactorsRouter.makeState(this.props);
  mounted = compact([
    this.props.initial ||
    get(first(React.Children.toArray(this.props.children)), 'props.name')
  ]);

  constructor(props) {
    super(props);
    this.name = props.name;
    ReactorsRouter.routers[this.name] = this;
  }

  componentWillReceiveProps = nextProps => {
    let nextState = {};
    const prevChildren = React.Children.toArray(this.props.children);
    const nextChildren = React.Children.toArray(nextProps.children);
    if (prevChildren.length !== nextChildren.length) {
      nextState = ReactorsRouter.makeState(nextProps);
    }
    this.setState(nextState, () => {
      const fullWidth = this.getFullWidth();
      const node = ReactDOM.findDOMNode(this);
      node.querySelector('.reactors-router-animated')
        .style.width = `${fullWidth}px`;
    });
  };
  componentDidUpdate = (prevProps, prevState) => {
    if (prevState.current !== this.state.current) {
      const routes = React.Children
        .toArray(this.props.children)
        .filter(route => includes(this.mounted, route.props.name));
      let index = findIndex(
        routes,
        route => route.props.name === this.state.current,
      );
      if (index === -1) {
        index = 0;
      }
      Animated
        .timing(this.offsetX, {toValue: -(this.props.width * index)})
        .start();
    }
  };

  render = () => (
    <View
      style={[
        {
          height: this.props.height,
          overflow: 'auto',
          position: 'relative',
          width: this.props.containerWidth || this.props.width,
        },
        this.props.containerStyle,
      ]}
    >
      <Animated
        className="reactors-router-animated"
        style={{
          flexDirection: 'row',
          height: this.props.height,
          transform: [{translateX: this.offsetX}],
          width: this.getFullWidth(),
          ...this.props.innerContainerStyle
        }}
      >
        {React.Children.toArray(this.props.children).map(child => (
          <View
            key={child.props.name}
            style={pick(this.props, ['height', 'width'])}
          >
            {includes(this.mounted, child.props.name) && (
              <Route
                {...omit(child.props, ['children'])}
                width={this.props.width}
              >
                {child.props.children}
              </Route>
            )}
          </View>
        ))}
      </Animated>
    </View>
  );

  offsetX = new Animated.Value(0);

  getCurrentRoute = () => this.state.current;
  getHeight = () => this.props.height;
  getWidth = () => this.props.width;
  getFullWidth = () => this.props.width * compact(this.mounted).length;
  go = (routeName, cb) => {
    if (!includes(this.mounted, routeName)) {
      this.mounted.push(routeName);
    }
    this.setState({current: routeName}, cb);
  };
  hasRoute = (routeName) => this.state.routes.some(
    route => route.props.name === routeName
  );
}

==> reactors-router-3.1.26.tgz: package/app/Router.js <==
// @flow
import {Animated, View} from 'reactors';
import compact from 'lodash/compact';
import findIndex from 'lodash/findIndex';
import first from 'lodash/first';
import get from 'lodash/get';
import includes from 'lodash/includes';
import omit from 'lodash/omit';
import pick from 'lodash/pick';
import React, {Component} from 'react';
import ReactDOM from 'react-dom';

import Route from './Route';

type $ReactorsRouterProps = {
  containerStyle: any,
};

export default class ReactorsRouter extends Component {

  static routers = {};

  static Route = Route;

  static get = name => ReactorsRouter.routers[name];

  static getRoute = (routeName, routes, mounted) => {
    let current;
    let currentIndex;
    routes.forEach((route, index) => {
      if (
        route.props.name === routeName &&
        includes(mounted, route.props.name)
      ) {
        current = route;
        currentIndex = index;
      }
    });
    return {...current, index: currentIndex};
  };

  static makeState = (props) => {
    const routes = React.Children.toArray(props.children);
    const currentRoute = ReactorsRouter.getRoute(props.initial, routes);
    const state = {routes};
    if (currentRoute) {
      state.current = currentRoute.name;
    } else {
      state.current = first(routes).name;
    }
    return state;
  };

  state = ReactorsRouter.makeState(this.props);
  mounted = compact([
    this.props.initial ||
    get(first(React.Children.toArray(this.props.children)), 'props.name')
  ]);

  constructor(props) {
    super(props);
    this.name = props.name;
    ReactorsRouter.routers[this.name] = this;
  }

  componentWillReceiveProps = nextProps => {
    let nextState = {};
    const prevChildren = React.Children.toArray(this.props.children);
    const nextChildren = React.Children.toArray(nextProps.children);
    if (prevChildren.length !== nextChildren.length) {
      nextState = ReactorsRouter.makeState(nextProps);
    }
    this.setState(nextState, () => {
      const fullWidth = this.getFullWidth();
      const node = ReactDOM.findDOMNode(this);
      node.querySelector('.reactors-router-animated')
        .style.width = `${fullWidth}px`;
    });
  };
  componentDidUpdate = (prevProps, prevState) => {
    if (prevState.current !== this.state.current) {
      const routes = React.Children
        .toArray(this.props.children)
        .filter(route => includes(this.mounted, route.props.name));
      let index = findIndex(
        routes,
        route => route.props.name === this.state.current,
      );
      if (index === -1) {
        index = 0;
      }
      Animated
        .timing(this.offsetX, {toValue: -(this.props.width * index)})
        .start();
    }
  };

  render = () => (
    <View
      style={[
        {
          height: this.props.height,
          overflow: 'auto',
          position: 'relative',
          width: this.props.containerWidth || this.props.width,
          boxSizing: 'border-box',
        },
        this.props.containerStyle,
      ]}
    >
      <Animated
        className="reactors-router-animated"
        style={{
          flexDirection: 'row',
          height: this.props.height,
          transform: [{translateX: this.offsetX}],
          width: this.getFullWidth(),
          boxSizing: 'border-box',
          ...this.props.innerContainerStyle,
        }}
      >
        {React.Children.toArray(this.props.children).map(child => (
          <View
            key={child.props.name}
            style={[{
              ...pick(this.props, ['height', 'width']),
              boxSizing: 'border-box',
            }, this.props.routeStyle]}
          >
            {includes(this.mounted, child.props.name) && (
              <Route
                {...omit(child.props, ['children'])}
                width={this.props.width}
                style={this.props.routeStyle}
              >
                {child.props.children}
              </Route>
            )}
          </View>
        ))}
      </Animated>
    </View>
  );

  offsetX = new Animated.Value(0);

  getCurrentRoute = () => this.state.current;
  getHeight = () => this.props.height;
  getWidth = () => this.props.width;
  getFullWidth = () => this.props.width * compact(this.mounted).length;
  go = (routeName, cb) => {
    if (!includes(this.mounted, routeName)) {
      this.mounted.push(routeName);
    }
    this.setState({current: routeName}, cb);
  };
  hasRoute = (routeName) => this.state.routes.some(
    route => route.props.name === routeName
  );
}
